Court of Appeals of Virginia Unpublished Opinions in PDF Format
Description: CAV Virginia Published Opinions
Keywords: CAV Virginia Published Opinions

Home > Virginia's Court System > Court of Appeals of Virginia > Court of Appeals of Virginia Unpublished Opinions

# Court of Appeals of Virginia Unpublished Opinions

These opinions are available as Adobe Acrobat PDF documents. The Adobe Acrobat Viewer (free from Adobe) allows you to view and print PDF documents.

0423134 Michael R. Pliuskaitis v. Teresa M. Pliuskaitis 10/08/2013
Summary affirmance – final decree of divorce affirmed

0958133 Island Creek Coal Company and Wells Fargo Disability v. Danny Wilson 10/08/2013
Summary affirmance – no error in commission’s decision finding appellee’s current symptoms were causally related to a 1989 work injury and that he is entitled to payment of medical treatment and medication

0980134 Harry William Hall v. Freestate Electrical Company, Inc. and American Home Assurance Company 10/08/2013
Summary affirmance – no error in commission’s finding that appellant’s claim is barred by res judicata

1005131 Charles O. Willis v. Coleman Construction Corporation and North River Insurance Company 10/08/2013
Commission’s finding that appellant’s claim was barred by res judicata affirmed

1084132 Mischelle Brown-Mayo v. County of Chesterfield 10/08/2013
Summary affirmance – no error in commission’s decision terminating an award of wage loss benefits on the ground that appellant’s current disability is unrelated to the compensable accident

1183123 Daquan Lajames Saunders v. Commonwealth of Virginia 10/08/2013
No error in appellant’s conviction of first-degree murder where evidence was sufficient to prove premeditation

1197123 Terry Wayne Turner v. City of Harrisonburg 10/08/2013
Trial court did not err in convicting appellant of a zoning ordinance for storing four inoperable vehicles on property owned by appellant’s mother and occupied by appellant

1235123 Theodis Thomas Smith, Jr. v. Commonwealth of Virginia 10/08/2013
Trial court’s denial of appellant’s motion to strike Juror 12 based on her friendship with a police officer who was a potential witness affirmed; appellant’s other arguments regarding Juror 12 waived

1537121 Ronald William Wethington, Jr. v. Commonwealth of Virginia 10/08/2013
Trial court did not err in denying appellant’s motion to suppress where police officer could have reasonably believed that appellant had violated the law by following more closely than is reasonable and prudent

1587123 Michael Paul Cairo v. Commonwealth of Virginia 10/08/2013
Appellant’s conviction of grand larceny affirmed where victim’s testimony was sufficient to prove value of stolen stove exceeded the $200 threshold

2090122 Shari Sims-Bernard v. Stephen P. Bernard 10/08/2013
Trial court’s ruling awarding sole legal custody of parties’ children to appellee and ordering that appellant’s visitation with the children be supervised affirmed; appellant’s issue regarding her motion for evaluation waived where she failed to request a ruling from the trial court

0499134 Berrak Tartaglino v. Frederick Robert Tartaglino 10/01/2013
Summary affirmance – trial court did not err in denying appellant’s request to terminate her children’s therapy

0819131 Cleo Dickerson v. City of Virginia Beach Department of Human Services 10/01/2013
Summary affirmance – Court is unable to review appellant’s assignments of error raised on appeal for her failure to provide an adequate record on appeal and her failure to comply with procedural rules

1160121 Jeffrey Alan Hurly, s/k/a Jefferey Allen Hurley v. Commonwealth of Virginia 10/01/2013
Trial court did not err in refusing to allow appellant to withdraw what he characterizes as a guilty plea to his probation revocation where counsel’s stipulation was not a guilty plea

0495132 Jerome Travis, Sr. v. Virginia Department of Social Services 09/24/2013
Summary affirmance – no error in trial court’s holding that substantial evidence supported the agency’s finding that appellant’s appeal was not timely filed

0739131 John Junior Martinez, Sr. v. City of Portsmouth Department of Social Services 09/24/2013
Summary affirmance – trial court did not err in terminating appellant’s parental rights to his child

0919102 William Edward Tuma v. Commonwealth of Virginia 09/24/2013
Upon Remand from the Supreme Court – trial court correctly refused to admit videotape into evidence where appellant had not reviewed the evidence at the time he sought to introduce it and was unable to lay any foundation to support its introduction

1067122 Damon Jamel Bradshaw v. Commonwealth of Virginia 09/24/2013
Trial court did not err in denying appellant’s motion to dismiss second charge of possession of a firearm by a convicted felon where act of transporting firearm in vehicle was separate and distinct from possession of firearm in bedroom

1350122 Damon Jamel Bradshaw v. Commonwealth of Virginia 09/24/2013
Trial court did not err in denying appellant’s motion to dismiss second charge of possession of a firearm by a convicted felon where act of transporting firearm in vehicle was separate and distinct from possession of firearm in bedroom

1452122 Lee Alden Mooney v. Commonwealth of Virginia 09/24/2013
Trial court did not err in revoking appellant’s suspended sentence and probation where trial court had authority to consider entire period of time from original suspension of appellant’s sentence in 2007 through the revocation hearing in 2012 and was not limited to reconsidering the terms of the 2011 suspension

Home | Virginia's Court System | Online Services | Case Status and Information | Court Administration | Directories | Forms | Judicial Branch Agencies | Programs